==> ragel-1.2.2.tar.gz: ragel-1.2.2/fsmcodegen.h <==
/*
 *  Copyright 2001 Adrian Thurston <adriant@ragel.ca>
 */

/*  This file is part of Ragel.
 *
 *  Ragel is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 * 
 *  Ragel is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with Ragel; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 */

#ifndef _FSMCODEGEN_H
#define _FSMCODEGEN_H

#include <iostream>
#include <fstream>
#include "fsmmachine.h"
#include "parsetree.h"
#include "bstmap.h"

class FsmCodeGen;
typedef void (*SectionType)(FsmCodeGen *codeGen);

/** class FsmCodeGen */
class FsmCodeGen
{
public:
	FsmCodeGen( char *fsmName, FsmMachine<int> *machine, 
			ParseData *parseData, ostream &out );
	virtual ~FsmCodeGen() {}

	virtual void writeOutHeader() { }
	virtual void writeOutCode() { }

protected:

	std::ostream &FSM_NAME();
	std::ostream &STRUCT_DATA();
	std::ostream &INIT_CODE();
	std::ostream &ANY_FUNCS() ;
	std::ostream &ANY_INDICIES() ;
	std::ostream &START_STATE_OFFSET() ;
	std::ostream &FUNCTIONS() ;

	char *getCodeBuiltin(int index);

	char *fsmName;
	FsmMachine<int> *machine;
	ParseData *parseData;
	ostream &out;

	/* These are used in all machines generators for generic writing 
	 * of out functions. */
	virtual void stateOutFunc(FsmMachState *state) { }
	virtual void transFunc(FsmMachTrans *trans) { }
};

#endif /* _FSMCODEGEN_H */

==> ragel-1.3.3.tar.gz: ragel-1.3.3/fsmcodegen.h <==
/*
 *  Copyright 2001 Adrian Thurston <adriant@ragel.ca>
 */

/*  This file is part of Ragel.
 *
 *  Ragel is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 * 
 *  Ragel is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with Ragel; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 */

#ifndef _FSMCODEGEN_H
#define _FSMCODEGEN_H

#include <iostream>
#include <fstream>
#include "fsmmachine.h"
#include "parsetree.h"
#include "bstmap.h"

class FsmCodeGen;
typedef void (*SectionType)(FsmCodeGen *codeGen);

/*
 * class FsmCodeGen
 */
class FsmCodeGen
{
public:
	FsmCodeGen( char *fsmName, FsmMachine *machine, 
			ParseData *parseData, ostream &out );
	virtual ~FsmCodeGen() {}

	virtual void writeOutHeader() { }
	virtual void writeOutCode() { }

protected:

	std::ostream &FSM_NAME();
	std::ostream &STRUCT_DATA();
	std::ostream &INIT_CODE();
	std::ostream &ANY_FUNCS() ;
	std::ostream &ANY_INDICIES() ;
	std::ostream &START_STATE_OFFSET() ;
	std::ostream &FUNCTIONS() ;

	char *getCodeBuiltin(int index);
	bool anyTransFuncs();
	bool anyIndicies();

	char *fsmName;
	FsmMachine *machine;
	ParseData *parseData;
	ostream &out;

	/* These are used in all machines generators for generic writing 
	 * of out functions. */
	virtual void stateOutFunc(FsmMachState *state) { }
	virtual void transFunc(FsmMachTrans *trans) { }
};

#endif /* _FSMCODEGEN_H */
